/**************************************************************************************
The following GAUSS program illustrates how to compute the two maximum test statistics
in Huo and Cho (2020) and their p-values that test the following hypotheses:

H0 versus H1    and     G0 versus G1,

respectively, where

H0: Covariance matrix is computed by error term that is conditionally homoskedastic and
    serially uncorrelated;

H1: Covariance matrix is computed by error term that may be conditionally heteroskedastic
    or serially correlated;

G0: Covariance matrix is computed by error term that is conditionally heteroskedastic but
    serially uncorrelated; and

G1: Covariance matrix is computed by error term that is conditionally heteroskedastic but
    serially uncorrelated.

Here, we assumed a linear model for the conditional mean equation to test the above 
hypotheses, and the unknown parameters are estimated by the OLS estimation. Three 
covariance matrix estimators are required to test H0 vs H1 and G0 vs. G1: the first 
covariance matrix estimator is obtained by assuming conditional homoskedasticity; the 
second covariance matrix estimator is obtained by the HC covariance matrix estimator 
(White 1980); and the final covariance matrix estimator is estimated by the HAC covariance 
matrix estimator using Andrews's (1991) kernel. 

Jan. 28, 2020.
Lijuan and Jin Seo Cho
******************************************************************************************/

new;
library pgraph;
#include andrews.prc;
#include powmat.prc;
#include pyeq1.prc;
#include pyeq2.prc;
#include pytest.prc;
#include pyeqp.prc;

// generating an illustrative data set
nnn = 200;
xx0 = rndn(nnn,2);
xxx = ones(nnn,1)~xx0;
uuu = rndn(nnn,1);
yyy = xxx*ones(cols(xxx),1) + uuu;

// inputs for computing the max tests
ind = xxx;    /* regressors */ 
dep = yyy;    /* dependent variable */
its = 10000;  /* number of bootstrap replications */

// computing the max tests
{tst, pp} = pyeqp(dep, ind, its);

output file = inference.txt on; 
print; format /rz 10, 5;
print "=========================";
print "testing covariane matrics";
print "=========================";
print "testing result: H0 vs. H1";
print "=========================";
print "max test =" tst[1,1];
print "p-value  =" pp[1,1] "%";
print "=========================";
print "testing result: G0 vs. G1";
print "=========================";
print "max test =" tst[1,2];
print "p-value  =" pp[1,2] "%";
print "=========================";
